<?php 
/**
 * Copyright oceanwebguru.com 2022
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License version 3.0
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to https://devdocs.prestashop.com/ for more information.
 *
 * @author    Radadiya Ajay <aradadiya163@rest.com>
 * @copyright oceanwebguru.com 2022
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License version 3.0
 */
if (!defined('_PS_VERSION_')) {
    exit;
}
class OcPrivateShop extends Module
{
    public function __construct()
    {
        $this->module_key = '864a5c9aad63211ee9fdf49af3af841d';
        $this->name = 'ocprivateshop';
        $this->tab = 'front_office_features';
        $this->version = '1.0.1';
        $this->author = 'Ajay Radadiya';
        $this->need_instance = 0;
        $this->ps_versions_compliancy = [
            'min' => '1.6',
            'max' => _PS_VERSION_,
        ];
        $this->bootstrap = true;
        parent::__construct();
        $this->displayName = $this->l('OC Build Private Shop');
        $this->description = $this->l('Build private shop for prestashop.');
        $this->confirmUninstall = $this->l('Are you sure you want to uninstall?');
        if (!Configuration::get('MYMODULE_NAME')) {
            $this->warning = $this->l('No name provided');
        }
    }

    public function install()
    {
        if (!parent::install() or
            !$this->registerHook('displayBackOfficeHeader') or
            !$this->registerHook('displayProductListReviews') or
            !$this->registerHook('displayProductPriceBlock') or
            !$this->registerHook('actionAuthentication') or
            !$this->registerHook('header')) {
            return false;
        }

        return true;
    }

    public function hookActionAuthentication($params)
    {
        $OCPS_LOGIN_REDIRECTURL = Configuration::get('OCPS_LOGIN_REDIRECTURL');
        if (!empty($OCPS_LOGIN_REDIRECTURL)) {
            Tools::redirect($OCPS_LOGIN_REDIRECTURL);

            exit();
        }
    }

    public function hookDisplayHeader($params)
    {
        $frparams = $this->getParams();
        $languageId = Context::getContext()->language->id;
        $controller = Dispatcher::getInstance()->getController();
        $id_cms = (int)Tools::getValue('id_cms');
        $pages = CMS::getCMSPages($languageId);
        $OCPS_LOGINTOSEE_PRICETXT = Configuration::get('OCPS_LOGINTOSEE_PRICETXT');
        $OCPS_LOGINTOSEE_PRICETXT_CLR = Configuration::get('OCPS_LOGINTOSEE_PRICETXT_CLR');
        $OCPS_LOGINTOSEE_PRICETXT_BGCLR = Configuration::get('OCPS_LOGINTOSEE_PRICETXT_BGCLR');
        $OCPS_LOGINTOSEE_PRICETXT_HOVERCLR = Configuration::get('OCPS_LOGINTOSEE_PRICETXT_HOVERCLR');
        $OCPS_LOGINTOSEE_PRICETXT_HOVERBGCLR = Configuration::get('OCPS_LOGINTOSEE_PRICETXT_HOVERBGCLR');
        $this->context->smarty->assign([
            'frparams' => $frparams,
            'authenloginpagelink' => $this->context->link->getPageLink('authentication', true),
        ]);
        $OCPS_FORGUEST_USERS = Configuration::get('OCPS_FORGUEST_USERS');
        $OCPS_PROPRICE_ATCBTN = Configuration::get('OCPS_PROPRICE_ATCBTN');
        $this->context->controller->addCSS($this->_path . '/views/css/ocprivateshopfront.css', 'all');
        $OCPS_FOR_SPECIFICUSER = json_decode(Configuration::get('OCPS_FOR_SPECIFICUSER'),true);
        $customerGroups = Context::getContext()->customer->getGroups();
        if (!Context::getContext()->customer->isLogged()) {
            if ($OCPS_FORGUEST_USERS == 'no') {
                if ($OCPS_PROPRICE_ATCBTN == 'yes') {
                    if (isset($this->context->controller->php_self)) {
                        $ocpstextcontent = [
                            'ocprivatecontent' => $this->fetch('module:ocprivateshop/views/templates/hook/customproductprices.tpl'),
                            'ocps_controller' => $this->context->controller->php_self,
                        ];
                        $this->context->controller->addJS($this->_path . '/views/js/ocpsfront.js', 'all');
                        Media::addJsDef(['ocpstextcontent' => $ocpstextcontent]);
                    }
                    if ($controller == 'cms') {
                        $cmsPageId = Tools::getValue('id_cms');
                        $OCPSCMSPAGES = json_decode(Configuration::get('OCPSCMSPAGES'),true);
                        if (!empty($OCPSCMSPAGES)) {  
                            if(in_array($cmsPageId, $OCPSCMSPAGES)){
                                if (Tools::getIsset('controller') && Tools::getValue('controller') !== 'authentication') {
                                    $loginUrl = $this->context->link->getPageLink('authentication', true);
                                    Tools::redirect($loginUrl);
                                    exit();
                                }
                            }
                        }
                    }
                    $OCPS_CMSCATEGORY = json_decode(Configuration::get('OCPS_CMSCATEGORY'),true);
                    $categoryId = (int) Tools::getValue('id_category');
                    if(!empty($categoryId) && !empty($OCPS_CMSCATEGORY)){
                        if (in_array($categoryId, $OCPS_CMSCATEGORY)) {
                            if (Tools::getIsset('controller') && Tools::getValue('controller') !== 'authentication') {
                                $loginUrl = $this->context->link->getPageLink('authentication', true);
                                Tools::redirect($loginUrl);
                                exit();
                            }
                        }
                    }
                }
            } else {
                if (Tools::getIsset('controller') && Tools::getValue('controller') !== 'authentication') {
                    $loginUrl = $this->context->link->getPageLink('authentication', true);
                    Tools::redirect($loginUrl);
                    exit();
                }
            }
        } else {
            if ($OCPS_FORGUEST_USERS == 'no') {
                if (!empty($OCPS_FOR_SPECIFICUSER)) {
                    if (!empty(array_intersect($customerGroups, $OCPS_FOR_SPECIFICUSER))) {
                        if ($OCPS_PROPRICE_ATCBTN == 'yes') {
                            if (isset($this->context->controller->php_self)) {
                                $ocpstextcontent = [
                                    'ocprivatecontent' => $this->fetch('module:ocprivateshop/views/templates/hook/customproductprices.tpl'),
                                    'ocps_controller' => $this->context->controller->php_self,
                                ];
                                $this->context->controller->addJS($this->_path . '/views/js/ocpsfront.js', 'all');
                                Media::addJsDef(['ocpstextcontent' => $ocpstextcontent]);
                            }
                        }
                    }
                }
            }
        }
    }

    public function hookDisplayProductListReviews($params)
    {
        $product = $params['product'];
        $frparams = $this->getParams();
        $OCPS_FORGUEST_USERS = Configuration::get('OCPS_FORGUEST_USERS');
        $OCPS_PROPRICE_ATCBTN = Configuration::get('OCPS_PROPRICE_ATCBTN');
        $OCPSALLPRODUCTS = json_decode(Configuration::get('OCPSALLPRODUCTS'),true);
        $OCPSALL_PROCATEGORIES = json_decode(Configuration::get('OCPSALL_PROCATEGORIES'),true);
        $productObj = new Product($product['id_product'], false, $this->context->language->id);
        $productCategories = $productObj->getCategories();
        $OCPS_FOR_SPECIFICUSER = json_decode(Configuration::get('OCPS_FOR_SPECIFICUSER'),true);
        $customerGroups = Context::getContext()->customer->getGroups();
        $this->context->smarty->assign([
            'frparams' => $frparams,
            'authenloginpagelink' => $this->context->link->getPageLink('authentication', true),
        ]);
        if (!Context::getContext()->customer->isLogged()) {
            if($OCPS_FORGUEST_USERS == 'no'){
                if ($OCPS_PROPRICE_ATCBTN == 'yes') {
                    if (!empty($OCPSALLPRODUCTS)) {
                        if (in_array($product['id_product'], $OCPSALLPRODUCTS)) {
                            return $this->display(__FILE__, 'views/templates/hook/customproductprices.tpl');
                        }
                    }
                    if (!empty($OCPSALL_PROCATEGORIES)) {
                        if (!empty(array_intersect($productCategories, $OCPSALL_PROCATEGORIES))) {
                            return $this->display(__FILE__, 'views/templates/hook/customproductprices.tpl');
                        }
                    }
                }
            }
        } else {
            if ($OCPS_FORGUEST_USERS == 'no') {
                if (!empty($OCPS_FOR_SPECIFICUSER)) {
                    if (!empty(array_intersect($customerGroups, $OCPS_FOR_SPECIFICUSER))) {
                        if ($OCPS_PROPRICE_ATCBTN == 'yes') {
                            if (!empty($OCPSALLPRODUCTS)) {
                                if (in_array($product['id_product'], $OCPSALLPRODUCTS)) {
                                    return $this->display(__FILE__, 'views/templates/hook/customproductprices.tpl');
                                }
                            }
                            if (!empty($OCPSALL_PROCATEGORIES)) {
                                if (!empty(array_intersect($productCategories, $OCPSALL_PROCATEGORIES))) {
                                    return $this->display(__FILE__, 'views/templates/hook/customproductprices.tpl');
                                }
                            }
                        }
                    }
                }
            }
        }
    }

    public function hookDisplayProductPriceBlock($params)
    {
        $productId = $params['product']['id_product'];
        $OCPS_LOGINTOSEE_PRICETXT = Configuration::get('OCPS_LOGINTOSEE_PRICETXT');
        $OCPS_LOGINTOSEE_PRICETXT_CLR = Configuration::get('OCPS_LOGINTOSEE_PRICETXT_CLR');
        $OCPS_LOGINTOSEE_PRICETXT_BGCLR = Configuration::get('OCPS_LOGINTOSEE_PRICETXT_BGCLR');
        $OCPS_FORGUEST_USERS = Configuration::get('OCPS_FORGUEST_USERS');
        $OCPS_PROPRICE_ATCBTN = Configuration::get('OCPS_PROPRICE_ATCBTN');
        $OCPSALLPRODUCTS = json_decode(Configuration::get('OCPSALLPRODUCTS'),true);
        $OCPSALL_PROCATEGORIES = json_decode(Configuration::get('OCPSALL_PROCATEGORIES'),true);
        $OCPS_FOR_SPECIFICUSER = json_decode(Configuration::get('OCPS_FOR_SPECIFICUSER'),true);
        $customerGroups = Context::getContext()->customer->getGroups();
        $productObj = new Product($productId, false, $this->context->language->id);
        $productCategories = $productObj->getCategories();
        $this->context->smarty->assign([
            'OCPS_LOGINTOSEE_PRICETXT' => $OCPS_LOGINTOSEE_PRICETXT,
            'OCPS_LOGINTOSEE_PRICETXT_CLR' => $OCPS_LOGINTOSEE_PRICETXT_CLR,
            'OCPS_LOGINTOSEE_PRICETXT_BGCLR' => $OCPS_LOGINTOSEE_PRICETXT_BGCLR,
        ]);
        $this->context->smarty->assign('hide_product_prices', true);
        if (!Context::getContext()->customer->isLogged()) {
            if($OCPS_FORGUEST_USERS == 'no'){
                if ($OCPS_PROPRICE_ATCBTN == 'yes') {
                    if (!empty($OCPSALLPRODUCTS)) {
                        if (in_array($productId, $OCPSALLPRODUCTS)) {
                            return ' ';
                        }
                    }
                    if (!empty($OCPSALL_PROCATEGORIES)) {
                        if (!empty(array_intersect($productCategories, $OCPSALL_PROCATEGORIES))) {
                            return ' ';
                        }
                    }
                }
            }
        } else {
            if($OCPS_FORGUEST_USERS == 'no'){
                if (!empty($OCPS_FOR_SPECIFICUSER)) {
                    if (!empty(array_intersect($customerGroups, $OCPS_FOR_SPECIFICUSER))) {
                        if ($OCPS_PROPRICE_ATCBTN == 'yes') {
                            if (!empty($OCPSALLPRODUCTS)) {
                                if (in_array($productId, $OCPSALLPRODUCTS)) {
                                    return ' ';
                                }
                            }
                            if (!empty($OCPSALL_PROCATEGORIES)) {
                                if (!empty(array_intersect($productCategories, $OCPSALL_PROCATEGORIES))) {
                                    return ' ';
                                }
                            }
                        }
                    }
                }
            }
        }
    }

    public function hookDisplayBackOfficeHeader()
    {
        if (Tools::getValue('configure') == 'ocprivateshop') {
            $this->context->controller->addJS($this->_path . '/views/js/select2.full.min.js', 'all');
            $this->context->controller->addCSS($this->_path . '/views/css/select2.min.css', 'all');
            $this->context->controller->addCSS($this->_path . '/views/css/coloris.min.css', 'all');
            $this->context->controller->addJS($this->_path . '/views/js/coloris.min.js', 'all');
            $this->context->controller->addJS($this->_path . '/views/js/ocprivateshopadmin.js', 'all');
        }
    }

    public function getParams()
    {
        $params = [
            'OCPS_FORGUEST_USERS',
            'OCPS_PROPRICE_ATCBTN',
            'OCPS_LOGINTOSEE_PRICETXT',
            'OCPS_LOGINTOSEE_PRICETXT_CLR',
            'OCPS_LOGINTOSEE_PRICETXT_BGCLR',
            'OCPSALLPRODUCTS',
            'OCPSALL_PROCATEGORIES',
            'OCPSCMSPAGES',
            'OCPS_CMSCATEGORY',
            'OCPS_FOR_SPECIFICUSER',
            'OCPS_LOGIN_REDIRECTURL',
            'OCPS_LOGINTOSEE_PRICETXT_HOVERBGCLR',
            'OCPS_LOGINTOSEE_PRICETXT_HOVERCLR',
        ];
        $params = Configuration::getMultiple($params);
        extract($params);
        $params['OCPS_FORGUEST_USERS'] = ((empty($OCPS_FORGUEST_USERS)) ? 'yes' : $OCPS_FORGUEST_USERS);
        $params['OCPS_PROPRICE_ATCBTN'] = ((empty($OCPS_PROPRICE_ATCBTN)) ? 'yes' : $OCPS_PROPRICE_ATCBTN);
        $params['OCPS_LOGINTOSEE_PRICETXT'] = ((empty($OCPS_LOGINTOSEE_PRICETXT)) ? 'Login to see price' : $OCPS_LOGINTOSEE_PRICETXT);
        $params['OCPS_LOGINTOSEE_PRICETXT_CLR'] = ((empty($OCPS_LOGINTOSEE_PRICETXT_CLR)) ? '#ffffff' : $OCPS_LOGINTOSEE_PRICETXT_CLR);
        $params['OCPS_LOGINTOSEE_PRICETXT_BGCLR'] = ((empty($OCPS_LOGINTOSEE_PRICETXT_BGCLR)) ? '#000000' : $OCPS_LOGINTOSEE_PRICETXT_BGCLR);
        $params['OCPS_LOGINTOSEE_PRICETXT_HOVERBGCLR'] = ((empty($OCPS_LOGINTOSEE_PRICETXT_HOVERBGCLR)) ? '#ffffff' : $OCPS_LOGINTOSEE_PRICETXT_HOVERBGCLR);
        $params['OCPS_LOGINTOSEE_PRICETXT_HOVERCLR'] = ((empty($OCPS_LOGINTOSEE_PRICETXT_HOVERCLR)) ? '#000000' : $OCPS_LOGINTOSEE_PRICETXT_HOVERCLR);

        return $params;
    }

    public function getContent()
    {
        $output = '';
        if (Tools::isSubmit('OcPrivateShopTokens')) {
            Configuration::updateValue('OCPS_FORGUEST_USERS', Tools::getValue('OCPS_FORGUEST_USERS'));
            Configuration::updateValue('OCPS_PROPRICE_ATCBTN', Tools::getValue('OCPS_PROPRICE_ATCBTN'));
            Configuration::updateValue('OCPS_LOGINTOSEE_PRICETXT', Tools::getValue('OCPS_LOGINTOSEE_PRICETXT'));
            Configuration::updateValue('OCPS_LOGINTOSEE_PRICETXT_CLR', Tools::getValue('OCPS_LOGINTOSEE_PRICETXT_CLR'));
            Configuration::updateValue('OCPS_LOGINTOSEE_PRICETXT_BGCLR', Tools::getValue('OCPS_LOGINTOSEE_PRICETXT_BGCLR'));
            Configuration::updateValue('OCPSALLPRODUCTS', json_encode(Tools::getValue('OCPSALLPRODUCTS')));
            Configuration::updateValue('OCPSALL_PROCATEGORIES', json_encode(Tools::getValue('OCPSALL_PROCATEGORIES')));
            Configuration::updateValue('OCPSCMSPAGES', json_encode(Tools::getValue('OCPSCMSPAGES')));
            Configuration::updateValue('OCPS_CMSCATEGORY', json_encode(Tools::getValue('OCPS_CMSCATEGORY')));
            Configuration::updateValue('OCPS_FOR_SPECIFICUSER', json_encode(Tools::getValue('OCPS_FOR_SPECIFICUSER')));
            Configuration::updateValue('OCPS_LOGIN_REDIRECTURL', Tools::getValue('OCPS_LOGIN_REDIRECTURL'));
            Configuration::updateValue('OCPS_LOGINTOSEE_PRICETXT_HOVERBGCLR', Tools::getValue('OCPS_LOGINTOSEE_PRICETXT_HOVERBGCLR'));
            Configuration::updateValue('OCPS_LOGINTOSEE_PRICETXT_HOVERCLR', Tools::getValue('OCPS_LOGINTOSEE_PRICETXT_HOVERCLR'));
            $output .= $this->displayConfirmation($this->trans(
                'Settings updated.',
                [],
                'Admin.Global',
            ));
        }
        $ocpsallproducts = Product::getProducts(Context::getContext()->language->id, 0, 0, 'id_product', 'ASC');
        $ocpsproductscategories = Category::getCategories(Context::getContext()->language->id, false, false);
        $ocpspages = CMS::getCMSPages(Context::getContext()->language->id);
        $ocavaliblecmsids = json_decode(Configuration::get('OCPSALLPRODUCTS'),true);
        $ocavaliprocate = json_decode(Configuration::get('OCPSALL_PROCATEGORIES'),true);
        $ocavalicmspages = json_decode(Configuration::get('OCPSCMSPAGES'),true);
        $ocavalicmscategory = json_decode(Configuration::get('OCPS_CMSCATEGORY'),true);
        $ocpsgroupaccess = json_decode(Configuration::get('OCPS_FOR_SPECIFICUSER'),true);
        $cmscategories = Category::getSimpleCategories(Configuration::get('PS_LANG_DEFAULT'));

        if (isset($this->ps_version)) {
            $params = $this->getParams();
            $moduleAdminLink = Context::getContext()->link->getAdminLink('AdminModules', true, false, $params);
        } else {
            $comurl = '&configure=' . $this->name . '&module_name=' . $this->name;
            $moduleAdminLink = Context::getContext()->link->getAdminLink('AdminModules', true) . $comurl;
        }
        $currentPage = 'ocprivateshop';
        $page = Tools::getValue('page');
        if (!empty($page)) {
            $currentPage = Tools::getValue('page');
        }
        $params = $this->getParams();
        $this->context->smarty->assign([
            'module_name' => $this->name, 
            'module_version' => $this->version, 
            'moduleAdminLink' => $moduleAdminLink, 
            'module_display' => $this->displayName, 
            'currentPage' => $currentPage, 
            'ps_base_dir' => Tools::getHttpHost(true), 
            'ps_version' => _PS_VERSION_, 
            'isPs17' => isset($this->ps_version), 
            'ocprivateshop_params' => $params,
            'ocpsallproducts' => $ocpsallproducts,
            'ocpsproductscategories' => $ocpsproductscategories,
            'ocpspages' => $ocpspages,
            'ocavaliblecmsids' => $ocavaliblecmsids,
            'ocavaliprocate' => $ocavaliprocate,
            'ocavalicmspages' => $ocavalicmspages,
            'cmscategories' => $cmscategories,
            'ocavalicmscategory' => $ocavalicmscategory,
            'ocpsgroupaccess' => $ocpsgroupaccess,
        ]);
        $output .= '';

        return $output . $this->context->smarty->fetch($this->local_path . 'views/templates/admin/ocadminprivateshop.tpl');
    }
}
